#
# spec file for package python-pyface
#
# Copyright (c) 2019 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# Tests have a dependency loop with traitsui
%bcond_with     test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
%define         X_display         ":98"
Name:           python-pyface
Version:        6.0.0
Release:        lp151.2.1
Summary:        Traits-capable windowing framework
License:        BSD-3-Clause and EPL-1.0 and LGPL-2.1 and LGPL-3.0 and SUSE-Public-Domain
Group:          Development/Libraries/Python
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
Url:            https://github.com/enthought/pyface
Source:         https://files.pythonhosted.org/packages/source/p/pyface/pyface-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traits}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module qt5}
BuildRequires:  xorg-x11-server
%endif
Requires:       python-traits
Recommends:     python-Pygments
Recommends:     python-qt5
Recommends:     python-traitsui
Recommends:     python-wxWidgets
BuildArch:      noarch

%python_subpackages

%description
The pyface project contains a toolkit-independent GUI abstraction layer,
which is used to support the "visualization" features of the Traits package.
Thus, you can write code in terms of the Traits API (views, items, editors,
etc.), and let pyface and your selected toolkit and back-end take care of
the details of displaying them.

Part of the Enthought Tool Suite (ETS).

%prep
%setup -q -n pyface-%{version}

%build
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyface/sizers
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyface/sizers
%fdupes %{buildroot}%{$python_sitelib}/pyface/sizers
}

%if %{with test}
%check
export ETS_TOOLKIT=qt4
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

%{python_expand mkdir tester_%{$python_bin_suffix}
pushd tester_%{$python_bin_suffix}
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m nose.core -v pyface --exclude=wx
popd
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.txt README.rst TODO.txt
%license LICENSE.txt image_LICENSE*.txt
%{python_sitelib}/pyface/
%{python_sitelib}/pyface-%{version}-py*.egg-info

%changelog
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Use qt5 backend.
* Wed May  9 2018 toddrme2178@gmail.com
- Release 6.0.0
  + Enhancements
  * Tasks support for wxPython (#223, #247)
  * Qt5 Support (#170, #256, #264, #265, #268, #271, #279, #292)
  * Disentangling Pyface and TraitsUI (#221, #250)
  * EDM-based test runner (#243, #296, #298)
  * Improved toolkit selection (#259, #260, #276, #304, #305)
  * Move wxPython-specific code to pyface.wx (#261)
  * Single choice dialog for Qt toolkit (was already in wx toolkit) (#217)
  * Add ‘detail’ and ‘informative’ to window dialog helpers (#181)
  * Code coverage reporting (#214)
  * All Pyface widgets now have visible and enabled traits (#284)
  * Allow “qt” as a synonym for “qt4” (#304)
  * PythonShell widget history exposed via the API (#314)
  * Experimental PySide2 support (#303)
  + Fixes
  * Documentation fixes (#220, #231)
  * Testing and CI fixes (#224, #226, #239, #248, #252, #253, #257, #267, #270, #277, #278, #281, #283)
  * Fix bug updating Tasks window titles (#225)
  * Python 3 compatibility fixes (#228)
  * Remove use of cmp in the AdvancedEditorAreaPane (#237)
  * AutoPEP8 of Pyface codebase (#241)
  * Minor WxPython fixes (#230, #269, #275, #294)
  * Don’t use sendPostedEvents in Qt GUI.do_trait_later (#273)
  * Fix ordering of items when appending to an ActionManager default group (#290)
  * Explicit life-cycle for Qt event filters on Widgets (#300)
  * Fixes to ensure demos and examples work (#308)
- Use license tag
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Release 5.1.0
  + Enhancements
  * Added documentation on toolkit selection (#197)
  * Clarify the purpose of LayoutContainer construction args (#189)
  * Improve ETSConfig toolkit selection (#187)
  + Fixes
  * Fix restoring show_editor_area from saved perspective(#207)
  * Fix WorkbenchWindowLayout in Python 3 (#206)
  * Update SplitEditorAreaPane's active editor when focus changes under Qt (#203, #204)
  * Read-only CodeEditor should not allow adding newlines in View (#200)
  * Fix exception when closing all docks in a workbench window (#199)
  * Fix extended trait change description in qt dock pane (#194)
  * Fix Qt Workbench dock widget control in a workbench window (#192)
  * Fix double UnInit of AUI in ApplicationWindow under Wx (#184, #185)
  * Fix IPythonWidget syntax error (#178, #186)
  * Fix ProgressDialog timer labels #(183)
  * Fix Qt CodeWidget when focus goes out of a widget (#176, #177)
  * Fix Qt and Wx ProgressDialog for updating message (#176, #177)
* Tue Apr 12 2016 toddrme2178@gmail.com
- Relase 5.0.0
  - Features
  * Experimental support for Python 3 (#160, #161, #162, #163).
  * Experimental support for wxPython 3 (#168).
  - Enhancements
  * Make Qt 4 the default GUI toolkit (#172).
  - Fixes
  * Fix issue with reading unicode text from Qt clipboard (#159).
  * Remove usage of `logging.warn` in favour of `logger.warning` (#167).
* Fri Sep  4 2015 toddrme2178@gmail.com
- Release 4.5.2
  - Enhancements
  * Added many tests, increasing test coverage by about 10%% (PR#147)
  * Add continuous integration support for Windows and Qt via Appveyor (PR #154)
  * Use Travis CI's container infrastructure (PR #153)
  - Fixes
  * Stop TaskWindow layout running after window control destroyed (PR#156).
  * Fix file execution for PythonShell on Windows with Qt backend (PR#147).
  * Fix Group objects setting wrong trait when naming new Actions (PR#147).
  * Fix ActionItem change handler for `visible` trait (PR#147).
  * Fix failure to release application window from AUIManager in Wx (PR#147).
  * Fix missing import for qt4 confirmation dialog (PR#147).
  * Deprecate Wx as the default toolkit choice for Pyface (PR#150).
  * Improve error handling in toolkit imports; fix some import errors which
    made the Qt PythonEditor unavailable; and make pygments a formal requirement
    rather than implicit (PR#144).
- Release Release 4.5.1
  - Fixes
  * fix MANIFEST.in (PR#131).
  * Fix incompatibility with Pygments 2.x, which was causing tracebacks
    during syntax highlighting (PR#136).
- Release Release 4.5.0
  - Enhancements
  * Add testing assistants (Qt) (PR#118).
  * Support menus in toolbars (Qt) (PR#104).
  * keybindings update for other editor area classes (PR#103).
  * Change advanced editor area tab switching shortcut to Ctrl+PgUp/Down (PR#99).
  * ToolBar: Listen to Action name changes for toolbar actions (PR#90).
  - Fixes
  * Fix reference to attribute (PR#112).
  * Fixed wx 2.9 incompatibility bug in ProgressDialog (PR#106).
  * Qt CodeEditor pygments monkeypatch conflict with ipython (PR#100).
  * Documentation fix (PR#95).
  * Tooltip for first editor of SplitEditorAreaPane was broken (PR#108)
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 4.4.0
  * No upstream changelog
- Updated source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
